@@ -18,7 +18,7 @@ __docformat__ = "restructuredtext"
 # import standard packages
 
 # import Zope3 interfaces
-from zope.viewlet.interfaces import IViewletManager, IViewlet
+from zope.viewlet.interfaces import IViewlet
 
 # import local interfaces
 
@@ -27,9 +27,5 @@ from zope.viewlet.interfaces import IViewletManager, IViewlet
 # import local packages
 
 
-class IWorkflowViewletManager(IViewletManager):
-    """Marker interface for workflow viewlets manager"""
-
-
 class IWorkflowTransitionsViewlet(IViewlet):
     """Marker interface for workflow transitions viewlet"""
